==> green-core-1.68.3.tgz: package/chunks/chunk.QK3R23GV.js <==
import {
  __spreadProps,
  __spreadValues
} from "./chunk.SEHSDSX2.js";

// libs/core/src/utils/helpers/custom-element-scoping.ts
import { html as litHtml } from "lit";
import { customElement } from "lit/decorators.js";
var VER_SUFFIX = "-44e24e";
var ScopedElementRegistry = class {
  static get instance() {
    var _a;
    if (!((_a = globalThis.__gdsElementLookupTable) == null ? void 0 : _a[VER_SUFFIX]))
      globalThis.__gdsElementLookupTable = __spreadProps(__spreadValues({}, globalThis.__gdsElementLookupTable), {
        [VER_SUFFIX]: /* @__PURE__ */ new Map()
      });
    return globalThis.__gdsElementLookupTable[VER_SUFFIX];
  }
};
function scopedCustomElement(tagName) {
  const versionedTagName = tagName + VER_SUFFIX;
  ScopedElementRegistry.instance.set(tagName, versionedTagName);
  return function(classOrTarget, context) {
    classOrTarget.prototype.gdsElementName = tagName;
    if (customElements.get(versionedTagName))
      return;
    return customElement(versionedTagName)(
      classOrTarget,
      context
    );
  };
}
function unscopedCustomElement(tagName) {
  ScopedElementRegistry.instance.set(tagName, tagName);
  return function(constructor) {
    constructor.prototype.gdsElementName = tagName;
    return customElement(tagName)(constructor);
  };
}
var gdsCustomElement = (tagName) => {
  if (globalThis.GDS_DISABLE_VERSIONED_ELEMENTS) {
    return unscopedCustomElement(tagName);
  }
  return scopedCustomElement(tagName);
};
var templateCache = /* @__PURE__ */ new WeakMap();
function applyElementScoping(strings, ...values) {
  let modstrings = templateCache.get(strings);
  if (!modstrings) {
    modstrings = replaceTags(strings);
    modstrings.raw = replaceTags(strings.raw);
    templateCache.set(strings, modstrings);
  }
  return [modstrings, ...values];
}
var replaceTags = (inStr) => inStr.map((s) => {
  for (const [key, value] of ScopedElementRegistry.instance.entries()) {
    s = s.replace(new RegExp(`${key}(?![-a-z])`, "mg"), value);
  }
  return s;
});
function htmlTemplateTagFactory(extendedTag) {
  return (strings, ...values) => {
    if (globalThis.GDS_DISABLE_VERSIONED_ELEMENTS) {
      return extendedTag(strings, ...values);
    }
    const [modstrings, ...modvalues] = applyElementScoping(strings, ...values);
    return extendedTag(modstrings, ...modvalues);
  };
}
var html = htmlTemplateTagFactory(litHtml);
function getScopedTagName(tagName) {
  var _a;
  return (_a = ScopedElementRegistry.instance.get(tagName)) != null ? _a : tagName;
}
function getUnscopedTagName(tagName) {
  var _a;
  return (_a = [...ScopedElementRegistry.instance.entries()].find(
    ([, value]) => value === tagName
  )) == null ? void 0 : _a[0];
}

export {
  VER_SUFFIX,
  ScopedElementRegistry,
  gdsCustomElement,
  htmlTemplateTagFactory,
  html,
  getScopedTagName,
  getUnscopedTagName
};

==> green-core-1.68.4.tgz: package/chunks/chunk.QK3R23GV.js <==
import {
  __spreadProps,
  __spreadValues
} from "./chunk.SEHSDSX2.js";

// libs/core/src/utils/helpers/custom-element-scoping.ts
import { html as litHtml } from "lit";
import { customElement } from "lit/decorators.js";
var VER_SUFFIX = "-a96c36";
var ScopedElementRegistry = class {
  static get instance() {
    var _a;
    if (!((_a = globalThis.__gdsElementLookupTable) == null ? void 0 : _a[VER_SUFFIX]))
      globalThis.__gdsElementLookupTable = __spreadProps(__spreadValues({}, globalThis.__gdsElementLookupTable), {
        [VER_SUFFIX]: /* @__PURE__ */ new Map()
      });
    return globalThis.__gdsElementLookupTable[VER_SUFFIX];
  }
};
function scopedCustomElement(tagName) {
  const versionedTagName = tagName + VER_SUFFIX;
  ScopedElementRegistry.instance.set(tagName, versionedTagName);
  return function(classOrTarget, context) {
    classOrTarget.prototype.gdsElementName = tagName;
    if (customElements.get(versionedTagName))
      return;
    return customElement(versionedTagName)(
      classOrTarget,
      context
    );
  };
}
function unscopedCustomElement(tagName) {
  ScopedElementRegistry.instance.set(tagName, tagName);
  return function(constructor) {
    constructor.prototype.gdsElementName = tagName;
    return customElement(tagName)(constructor);
  };
}
var gdsCustomElement = (tagName) => {
  if (globalThis.GDS_DISABLE_VERSIONED_ELEMENTS) {
    return unscopedCustomElement(tagName);
  }
  return scopedCustomElement(tagName);
};
var templateCache = /* @__PURE__ */ new WeakMap();
function applyElementScoping(strings, ...values) {
  let modstrings = templateCache.get(strings);
  if (!modstrings) {
    modstrings = replaceTags(strings);
    modstrings.raw = replaceTags(strings.raw);
    templateCache.set(strings, modstrings);
  }
  return [modstrings, ...values];
}
var replaceTags = (inStr) => inStr.map((s) => {
  for (const [key, value] of ScopedElementRegistry.instance.entries()) {
    s = s.replace(new RegExp(`${key}(?![-a-z])`, "mg"), value);
  }
  return s;
});
function htmlTemplateTagFactory(extendedTag) {
  return (strings, ...values) => {
    if (globalThis.GDS_DISABLE_VERSIONED_ELEMENTS) {
      return extendedTag(strings, ...values);
    }
    const [modstrings, ...modvalues] = applyElementScoping(strings, ...values);
    return extendedTag(modstrings, ...modvalues);
  };
}
var html = htmlTemplateTagFactory(litHtml);
function getScopedTagName(tagName) {
  var _a;
  return (_a = ScopedElementRegistry.instance.get(tagName)) != null ? _a : tagName;
}
function getUnscopedTagName(tagName) {
  var _a;
  return (_a = [...ScopedElementRegistry.instance.entries()].find(
    ([, value]) => value === tagName
  )) == null ? void 0 : _a[0];
}

export {
  VER_SUFFIX,
  ScopedElementRegistry,
  gdsCustomElement,
  htmlTemplateTagFactory,
  html,
  getScopedTagName,
  getUnscopedTagName
};
